const path = require('path')
const PrerenderSPAPlugin = require('prerender-spa-plugin')
const Renderer = require('./render/index.js')

module.exports = (api, opts) => {
  api.chainWebpack(config => {
    config
      .when(process.env.NODE_ENV === 'production', config => {
        const option = opts.pluginOptions ? opts.pluginOptions.prerender || {} : {}
        const extendOption = {
          staticDir: path.resolve('dist'),
          routes: ['/'],
          renderer: new Renderer({
            headless: true,
            port: option.port || 8080
          }),
          server: {
            port: option.port || 8080
          },
          postProcess (renderedRoute) {
            renderedRoute.html = renderedRoute.html.replace('id="app"', 'id=app data-server-rendered="true"')
            return renderedRoute
          }
        }
        Object.assign(extendOption, option)
        if (option.renderer) {
          extendOption.renderer = new Renderer(extendOption.renderer)
        }
        config
          .plugin('prerender')
          .use(PrerenderSPAPlugin, [extendOption])
      })
  })
}
